==> karma-jspm-0.0.3.tgz: package/index.js <==
var cwd = process.cwd();
var glob = require("glob");
var path = require("path");


function flatten(structure) {
  return [].concat.apply([], structure);
}

function expandGlob(file) {
  return glob.sync(file.pattern || file).map(function (filePath) {
    return filePath.replace(/\//g, path.sep);
  });
};

var createPattern = function(path) {
  return {pattern: path, included: true, served: true, watched: false};
};

var createServedPattern = function(path){
  return {pattern: path, included: false, served: true, watched: true};
};

var initJspm = function(files, basePath, jspm, client) {
  // Allow Karma to serve all files within jspm_packages.
  // This allows jspm/SystemJS to load them
  files.unshift(createServedPattern(basePath + '/jspm_packages/**/*'));

  // Add SystemJS loader and jspm config
  files.unshift(createPattern(__dirname + '/src/adapter.js'));
  files.unshift(createPattern(cwd + '/config.js'));
  files.unshift(createPattern(cwd + '/jspm_packages/system@0.8.js'));
  files.unshift(createPattern(cwd + '/jspm_packages/es6-module-loader@0.8.js'));
  // files.unshift(createPattern(cwd + '/jspm_packages/traceur-runtime@0.0.56.js'));
  
  // Initialize jspm config if it wasn't specified in karma.conf.js
  if(!jspm)
    jspm = {};
  if(!jspm.files)
    jspm.files = [];
  if(!client.jspm)
    client.jspm = {};

  // Loop through all of jspm.files and do two things
  // 1. Add all the files as "served" files to the files array
  // 2. Expand out and globs to end up with actual files for jspm to load. 
  //    Store that in client.jspm.expandedFiles
  client.jspm.expandedFiles = flatten(jspm.files.map(function(file){
    files.push(createServedPattern(cwd + "/" + (file.pattern || file)));
    return expandGlob(file);
  }));
};

initJspm.$inject = ['config.files', 'config.basePath', 'config.jspm', 'config.client'];

module.exports = {
  'framework:jspm': ['factory', initJspm]
};

==> karma-jspm-0.0.4.tgz: package/index.js <==
var cwd = process.cwd();
var glob = require("glob");
var path = require("path");


function flatten(structure) {
  return [].concat.apply([], structure);
}

function expandGlob(file) {
  return glob.sync(file.pattern || file).map(function (filePath) {
    return filePath.replace(/\//g, path.sep);
  });
};

var createPattern = function(path) {
  return {pattern: path, included: true, served: true, watched: false};
};

var createServedPattern = function(path){
  return {pattern: path, included: false, served: true, watched: true};
};

var initJspm = function(files, basePath, jspm, client) {
  // Initialize jspm config if it wasn't specified in karma.conf.js
  if(!jspm)
    jspm = {};
  if(!jspm.config)
    jspm.config = "config.js";
  if(!jspm.files)
    jspm.files = [];
  if(!jspm.packages)
    jspm.packages = "jspm_packages/";
  if(!client.jspm)
    client.jspm = {};

  // Allow Karma to serve all files within jspm_packages.
  // This allows jspm/SystemJS to load them
  files.unshift(createServedPattern(basePath + '/' + jspm.packages + '**/*'));

  // Add SystemJS loader and jspm config
  files.unshift(createPattern(__dirname + '/src/adapter.js'));
  files.unshift(createPattern(cwd + '/' + jspm.config));
  files.unshift(createPattern(cwd + '/' + jspm.packages + 'system@0.8.js'));
  files.unshift(createPattern(cwd + '/' + jspm.packages + 'es6-module-loader@0.8.js'));

  // Loop through all of jspm.files and do two things
  // 1. Add all the files as "served" files to the files array
  // 2. Expand out and globs to end up with actual files for jspm to load. 
  //    Store that in client.jspm.expandedFiles
  client.jspm.expandedFiles = flatten(jspm.files.map(function(file){
    files.push(createServedPattern(cwd + "/" + (file.pattern || file)));
    return expandGlob(file);
  }));

  console.log(files);
};

initJspm.$inject = ['config.files', 'config.basePath', 'config.jspm', 'config.client'];

module.exports = {
  'framework:jspm': ['factory', initJspm]
};
